matminer.utils.tests package — matminer 0.9.1 documentation

# matminer.utils.tests package

## Submodules

## matminer.utils.tests.test_caching module

class matminer.utils.tests.test_caching.TestCaching(methodName='runTest')

  Bases: `PymatgenTest`

  test_cache()

## matminer.utils.tests.test_data module

class matminer.utils.tests.test_data.TestDemlData(methodName='runTest')

  Bases: `TestCase`

  Tests for the DemlData Class

  setUp()

    Hook method for setting up the test fixture before exercising it.

  test_get_oxidation()
  test_get_property()

class matminer.utils.tests.test_data.TestIUCrBondValenceData(methodName='runTest')

  Bases: `TestCase`

  setUp()

    Hook method for setting up the test fixture before exercising it.

  test_get_data()

class matminer.utils.tests.test_data.TestMEGNetData(methodName='runTest')

  Bases: `TestCase`

  setUp()

    Hook method for setting up the test fixture before exercising it.

  test_get_property()

class matminer.utils.tests.test_data.TestMagpieData(methodName='runTest')

  Bases: `TestCase`

  setUp()

    Hook method for setting up the test fixture before exercising it.

  test_get_oxidation()
  test_get_property()

class matminer.utils.tests.test_data.TestMatScholarData(methodName='runTest')

  Bases: `TestCase`

  setUp()

    Hook method for setting up the test fixture before exercising it.

  test_get_property()

class matminer.utils.tests.test_data.TestMixingEnthalpy(methodName='runTest')

  Bases: `TestCase`

  setUp()

    Hook method for setting up the test fixture before exercising it.

  test_get_data()

class matminer.utils.tests.test_data.TestPymatgenData(methodName='runTest')

  Bases: `TestCase`

  setUp()

    Hook method for setting up the test fixture before exercising it.

  test_get_oxidation()
  test_get_property()

## matminer.utils.tests.test_flatten_dict module

class matminer.utils.tests.test_flatten_dict.FlattenDictTest(methodName='runTest')

  Bases: `TestCase`

  test_flatten_nested_dict()

## matminer.utils.tests.test_io module

class matminer.utils.tests.test_io.IOTest(methodName='runTest')

  Bases: `PymatgenTestExtended`

  setUp()

    Hook method for setting up the test fixture before exercising it.

  tearDown()

    Hook method for deconstructing the test fixture after testing it.

  test_load_dataframe_from_json()
  test_store_dataframe_as_json()

class matminer.utils.tests.test_io.PymatgenTestExtended(methodName='runTest')

  Bases: `PymatgenTest`

  Reintroduces legacy methods from the PymatgenTest class.

  static assertDictsAlmostEqual(actual, desired, decimal=7, err_msg='', verbose=True) → bool

    Tests if entries in a dictionary are almost equal to a tolerance. The CamelCase naming is so that it is consistent with standard unittest methods.

    Modified from: https://github.com/materialsproject/pymatgen/blob/1156d0db2360a0ef32bfc1ba5c8314f7421755a3/pymatgen/util/testing.py#L80-L103

matminer.utils.tests.test_io.generate_json_files()

## Module contents